@@ -37,6 +37,7 @@
 #include "CIndexes.hxx"
 
 #include <tools/debug.hxx>
+#include <osl/diagnose.h>
 #include <cppuhelper/typeprovider.hxx>
 #include <comphelper/enumhelper.hxx>
 #include <comphelper/container.hxx>
@@ -91,8 +92,8 @@ ODBTable::ODBTable(connectivity::sdbcx::OCollection* _pTables
 {
     RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "dbaccess", "Ocke.Janssen@sun.com", "ODBTable::ODBTable" );
     DBG_CTOR(ODBTable, NULL);
-    DBG_ASSERT(getMetaData().is(), "ODBTable::ODBTable : invalid conn !");
-    DBG_ASSERT(_rName.getLength(), "ODBTable::ODBTable : name !");
+    OSL_ENSURE(getMetaData().is(), "ODBTable::ODBTable : invalid conn !");
+    OSL_ENSURE(_rName.getLength(), "ODBTable::ODBTable : name !");
     // TODO : think about collecting the privileges here, as we can't ensure that in getFastPropertyValue, where
     // we do this at the moment, the statement needed can be supplied by the connection (for example the SQL-Server
     // ODBC driver does not allow more than one statement per connection, and in getFastPropertyValue it's more
