@@ -29,7 +29,7 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_dbaccess.hxx"
 #include "JoinTableView.hxx"
-#include <tools/debug.hxx>
+#include <osl/diagnose.h>
 #include "querycontroller.hxx"
 #include "JoinDesignView.hxx"
 #include "dbu_qry.hrc"
@@ -171,8 +171,6 @@ void OScrollWindowHelper::Resize()
 // class OJoinTableView
 //==================================================================
 
-//const long WINDOW_WIDTH = 1000;
-//const long WINDOW_HEIGHT = 1000;
 DBG_NAME(OJoinTableView);
 //------------------------------------------------------------------------------
 OJoinTableView::OJoinTableView( Window* pParent, OJoinDesignView* pView )
@@ -183,7 +181,7 @@ OJoinTableView::OJoinTableView( Window* pParent, OJoinDesignView* pView )
     ,m_pDragWin( NULL )
     ,m_pSizingWin( NULL )
     ,m_pSelectedConn( NULL )
-    ,m_bTrackingInitiallyMoved(FALSE)
+    ,m_bTrackingInitiallyMoved(sal_False)
     ,m_pLastFocusTabWin(NULL)
     ,m_pView( pView )
     ,m_pAccessible(NULL)
@@ -214,7 +212,7 @@ IMPL_LINK( OJoinTableView, ScrollHdl, ScrollBar*, pScrollBar )
 {
     //////////////////////////////////////////////////////////////////////
     // Alle Fenster verschieben
-    ScrollPane( pScrollBar->GetDelta(), (pScrollBar == GetHScrollBar()), FALSE );
+    ScrollPane( pScrollBar->GetDelta(), (pScrollBar == GetHScrollBar()), sal_False );
 
     return 0;
 }
@@ -252,7 +250,7 @@ void OJoinTableView::Resize()
     }
 }
 //------------------------------------------------------------------------------
-ULONG OJoinTableView::GetTabWinCount()
+sal_uLong OJoinTableView::GetTabWinCount()
 {
     DBG_CHKTHIS(OJoinTableView,NULL);
     return m_aTableMap.size();
@@ -335,7 +333,7 @@ OTableWindowData* OJoinTableView::CreateImpl(const ::rtl::OUString& _rComposedNa
     return new OTableWindowData( NULL,_rComposedName,_sTableName, _rWinName );
 }
 //------------------------------------------------------------------------------
-void OJoinTableView::AddTabWin(const ::rtl::OUString& _rComposedName, const ::rtl::OUString& rWinName, BOOL /*bNewTable*/)
+void OJoinTableView::AddTabWin(const ::rtl::OUString& _rComposedName, const ::rtl::OUString& rWinName, sal_Bool /*bNewTable*/)
 {
     DBG_CHKTHIS(OJoinTableView,NULL);
     OSL_ENSURE(_rComposedName.getLength(),"There must be a table name supplied!");
@@ -432,9 +430,8 @@ void OJoinTableView::RemoveTabWin( OTableWindow* pTabWin )
 namespace
 {
     // -----------------------------------------------------------------------------
-    BOOL isScrollAllowed( OJoinTableView* _pView,long nDelta, BOOL bHoriz)
+    sal_Bool isScrollAllowed( OJoinTableView* _pView,long nDelta, sal_Bool bHoriz)
     {
-        BOOL bRet = TRUE;
         //////////////////////////////////////////////////////////////////////
         // adjust ScrollBar-Positions
         ScrollBar* pBar = _pView->GetVScrollBar();
@@ -444,40 +441,38 @@ namespace
         long nOldThumbPos = pBar->GetThumbPos();
         long nNewThumbPos = nOldThumbPos + nDelta;
         if( nNewThumbPos < 0 )
-            nNewThumbPos = 0;//	bRet = FALSE;
+            nNewThumbPos = 0;
         else if( nNewThumbPos > pBar->GetRangeMax() )
-            nNewThumbPos = pBar->GetRangeMax();// bRet = FALSE;
+            nNewThumbPos = pBar->GetRangeMax();
 
         if ( bHoriz )
         {
             if( nNewThumbPos == _pView->GetScrollOffset().X() )
-                return FALSE;
+                return sal_False;
         }
         else if ( nNewThumbPos == _pView->GetScrollOffset().Y() )
-            return FALSE;
+            return sal_False;
 
-        return bRet;
+        return sal_True;
     }
     // -----------------------------------------------------------------------------
-    BOOL getMovementImpl(OJoinTableView* _pView,const Point& _rPoint,const Size& _rSize,long& _nScrollX,long& _nScrollY)
+    sal_Bool getMovementImpl(OJoinTableView* _pView,const Point& _rPoint,const Size& _rSize,long& _nScrollX,long& _nScrollY)
     {
         _nScrollY = _nScrollX = 0;
         // data about the tab win
         Point aUpperLeft = _rPoint;
         // normalize with respect to visibility
         aUpperLeft -= _pView->GetScrollOffset();
-        //	aUpperLeft.Y() -= _pView->GetScrollOffset().Y();
         Point aLowerRight(aUpperLeft.X() + _rSize.Width(), aUpperLeft.Y() + _rSize.Height());
 
         // data about ourself
         Size aSize = _pView->getRealOutputSize(); //GetOutputSizePixel();
 
-        BOOL bVisbile = TRUE;
-        BOOL bFitsHor = (aUpperLeft.X() >= 0) && (aLowerRight.X() <= aSize.Width());
-        BOOL bFitsVert= (aUpperLeft.Y() >= 0) && (aLowerRight.Y() <= aSize.Height());
+        sal_Bool bVisbile = sal_True;
+        sal_Bool bFitsHor = (aUpperLeft.X() >= 0) && (aLowerRight.X() <= aSize.Width());
+        sal_Bool bFitsVert= (aUpperLeft.Y() >= 0) && (aLowerRight.Y() <= aSize.Height());
         if (!bFitsHor || !bFitsVert)
         {
-            // #100386# OJ
             if (!bFitsHor)
             {
                 // ensure the visibility of the right border
@@ -485,7 +480,6 @@ namespace
                     _nScrollX = aLowerRight.X() - aSize.Width() + TABWIN_SPACING_X;
 
                 // ensure the visibility of the left border (higher priority)
-                //	if ( (aUpperLeft.X() - _nScrollX) < 0 )
                 if ( aUpperLeft.X() < 0 )
                     _nScrollX = aUpperLeft.X() - TABWIN_SPACING_X;
             }
@@ -496,16 +490,15 @@ namespace
                 if ( aLowerRight.Y() > aSize.Height() )
                     _nScrollY = aLowerRight.Y() - aSize.Height() + TABWIN_SPACING_Y;
                 // upper border
-                //	if ( (aUpperLeft.Y() - _nScrollY) < 0 )
                 if ( aUpperLeft.Y() < 0 )
                     _nScrollY = aUpperLeft.Y() - TABWIN_SPACING_Y;
             }
 
             if ( _nScrollX ) // aSize.Width() > _rSize.Width() &&
-                bVisbile = isScrollAllowed(_pView,_nScrollX, TRUE);
+                bVisbile = isScrollAllowed(_pView,_nScrollX, sal_True);
 
             if ( _nScrollY ) // aSize.Height() > _rSize.Height() &&
-                bVisbile = bVisbile && isScrollAllowed(_pView,_nScrollY, FALSE);
+                bVisbile = bVisbile && isScrollAllowed(_pView,_nScrollY, sal_False);
 
             if ( bVisbile )
             {
@@ -513,9 +506,9 @@ namespace
                 sal_Int32 nVRangeMax = _pView->GetVScrollBar()->GetRangeMax();
 
                 if ( aSize.Width() + _pView->GetHScrollBar()->GetThumbPos() + _nScrollX > nHRangeMax )
-                    bVisbile = FALSE;
+                    bVisbile = sal_False;
                 if ( bVisbile && aSize.Height() + _pView->GetVScrollBar()->GetThumbPos() + _nScrollY > nVRangeMax )
-                    bVisbile = FALSE;
+                    bVisbile = sal_False;
             }
         }
 
@@ -524,7 +517,7 @@ namespace
     }
 } // end of ano namespace
 // -----------------------------------------------------------------------------
-BOOL OJoinTableView::isMovementAllowed(const Point& _rPoint,const Size& _rSize)
+sal_Bool OJoinTableView::isMovementAllowed(const Point& _rPoint,const Size& _rSize)
 {
     long nX,nY;
     return getMovementImpl(this,_rPoint,_rSize,nX,nY);
@@ -534,7 +527,6 @@ void OJoinTableView::EnsureVisible(const OTableWindow* _pWin)
 {
     // data about the tab win
     TTableWindowData::value_type pData = _pWin->GetData();
-    //	Point aUpperLeft = pData->GetPosition();
     EnsureVisible( pData->GetPosition() , pData->GetSize());
     Invalidate(INVALIDATE_NOCHILDREN);
 }
@@ -545,12 +537,12 @@ void OJoinTableView::EnsureVisible(const Point& _rPoint,const Size& _rSize)
 
     if ( getMovementImpl(this,_rPoint,_rSize,nScrollX,nScrollY) )
     {
-        BOOL bVisbile = TRUE;
+        sal_Bool bVisbile = sal_True;
         if (nScrollX)
-            bVisbile = ScrollPane(nScrollX, TRUE, TRUE);
+            bVisbile = ScrollPane(nScrollX, sal_True, sal_True);
 
         if (nScrollY)
-            bVisbile = bVisbile && ScrollPane(nScrollY, FALSE, TRUE);
+            bVisbile = bVisbile && ScrollPane(nScrollY, sal_False, sal_True);
     }
 }
 
@@ -565,8 +557,8 @@ void OJoinTableView::SetDefaultTabWinPosSize( OTableWindow* pTabWin )
     // Wenn kein Platz ist, wird die naechste Zeile ueberprueft.
     Size aOutSize = GetSizePixel();
     Point aNewPos( 0,0 );
-    USHORT nRow = 0;
-    BOOL bEnd = FALSE;
+    sal_uInt16 nRow = 0;
+    sal_Bool bEnd = sal_False;
     while( !bEnd )
     {
         //////////////////////////////////////////////////////////////////
@@ -582,7 +574,7 @@ void OJoinTableView::SetDefaultTabWinPosSize( OTableWindow* pTabWin )
 
         //////////////////////////////////////////////////////////////////
         // Belegte Bereiche dieser Zeile pruefen
-        OTableWindow* pOtherTabWin;// = GetTabWinMap()->First();
+        OTableWindow* pOtherTabWin;
         OTableWindowMapIterator aIter = m_aTableMap.begin();
         OTableWindowMapIterator aEnd = m_aTableMap.end();
         for(;aIter != aEnd;++aIter)
@@ -607,7 +599,7 @@ void OJoinTableView::SetDefaultTabWinPosSize( OTableWindow* pTabWin )
         if( (aNewPos.X()+TABWIN_WIDTH_STD)<aRowRect.Right() )
         {
             aNewPos.Y() = aRowRect.Top() + TABWIN_SPACING_Y;
-            bEnd = TRUE;
+            bEnd = sal_True;
         }
         else
         {
@@ -617,7 +609,7 @@ void OJoinTableView::SetDefaultTabWinPosSize( OTableWindow* pTabWin )
                 sal_Int32 nCount = m_aTableMap.size() % (nRow+1);
                 ++nCount;
                 aNewPos.Y() = nCount * TABWIN_SPACING_Y + (nCount-1)*CalcZoom(TABWIN_HEIGHT_STD);
-                bEnd = TRUE;
+                bEnd = sal_True;
             }
             else
                 nRow++;
@@ -679,7 +671,7 @@ void OJoinTableView::BeginChildMove( OTableWindow* pTabWin, const Point& rMouseP
     Point aMousePos = ScreenToOutputPixel( rMousePos );
     m_aDragOffset = aMousePos - pTabWin->GetPosPixel();
     m_pDragWin->SetZOrder(NULL, WINDOW_ZORDER_FIRST);
-    m_bTrackingInitiallyMoved = FALSE;
+    m_bTrackingInitiallyMoved = sal_False;
     StartTracking();
 }
 
@@ -704,10 +696,10 @@ void OJoinTableView::BeginChildSizing( OTableWindow* pTabWin, const Pointer& rPo
 }
 
 //------------------------------------------------------------------------------
-BOOL OJoinTableView::ScrollPane( long nDelta, BOOL bHoriz, BOOL bPaintScrollBars )
+sal_Bool OJoinTableView::ScrollPane( long nDelta, sal_Bool bHoriz, sal_Bool bPaintScrollBars )
 {
     DBG_CHKTHIS(OJoinTableView,NULL);
-    BOOL bRet = TRUE;
+    sal_Bool bRet = sal_True;
 
     //////////////////////////////////////////////////////////////////////
     // ScrollBar-Positionen anpassen
@@ -720,12 +712,12 @@ BOOL OJoinTableView::ScrollPane( long nDelta, BOOL bHoriz, BOOL bPaintScrollBars
             if( nNewThumbPos < 0 )
             {
                 nNewThumbPos = 0;
-                bRet = FALSE;
+                bRet = sal_False;
             }
             if( nNewThumbPos > GetHScrollBar()->GetRange().Max() )
             {
                 nNewThumbPos = GetHScrollBar()->GetRange().Max();
-                bRet = FALSE;
+                bRet = sal_False;
             }
             GetHScrollBar()->SetThumbPos( nNewThumbPos );
             nDelta = GetHScrollBar()->GetThumbPos() - nOldThumbPos;
@@ -737,12 +729,12 @@ BOOL OJoinTableView::ScrollPane( long nDelta, BOOL bHoriz, BOOL bPaintScrollBars
             if( nNewThumbPos < 0 )
             {
                 nNewThumbPos = 0;
-                bRet = FALSE;
+                bRet = sal_False;
             }
             if( nNewThumbPos > GetVScrollBar()->GetRange().Max() )
             {
                 nNewThumbPos = GetVScrollBar()->GetRange().Max();
-                bRet = FALSE;
+                bRet = sal_False;
             }
             GetVScrollBar()->SetThumbPos( nNewThumbPos );
             nDelta = GetVScrollBar()->GetThumbPos() - nOldThumbPos;
@@ -753,7 +745,7 @@ BOOL OJoinTableView::ScrollPane( long nDelta, BOOL bHoriz, BOOL bPaintScrollBars
     // Wenn ScrollOffset bereits an den Grenzen liegt, kein Neuzeichnen
     if( (GetHScrollBar()->GetThumbPos()==m_aScrollOffset.X()) &&
         (GetVScrollBar()->GetThumbPos()==m_aScrollOffset.Y()) )
-        return FALSE;
+        return sal_False;
 
     //////////////////////////////////////////////////////////////////////
     // ScrollOffset neu setzen
@@ -930,9 +922,9 @@ void OJoinTableView::MouseButtonUp( const MouseEvent& rEvt )
 void OJoinTableView::KeyInput( const KeyEvent& rEvt )
 {
     DBG_CHKTHIS(OJoinTableView,NULL);
-    USHORT nCode = rEvt.GetKeyCode().GetCode();
-    BOOL   bShift = rEvt.GetKeyCode().IsShift();
-    BOOL   bCtrl = rEvt.GetKeyCode().IsMod1();
+    sal_uInt16 nCode = rEvt.GetKeyCode().GetCode();
+    sal_Bool   bShift = rEvt.GetKeyCode().IsShift();
+    sal_Bool   bCtrl = rEvt.GetKeyCode().IsMod1();
 
     if( !bCtrl && !bShift && (nCode==KEY_DELETE) )
     {
@@ -953,11 +945,11 @@ void OJoinTableView::DeselectConn(OTableConnection* pConn)
     // die zugehoerigen Eitnraege in der ListBox des Tabellenfenster deselektieren
     OTableWindow* pWin = pConn->GetSourceWin();
     if (pWin && pWin->GetListBox())
-        pWin->GetListBox()->SelectAll(FALSE);
+        pWin->GetListBox()->SelectAll(sal_False);
 
     pWin = pConn->GetDestWin();
     if (pWin && pWin->GetListBox())
-        pWin->GetListBox()->SelectAll(FALSE);
+        pWin->GetListBox()->SelectAll(sal_False);
 
     pConn->Deselect();
     m_pSelectedConn = NULL;
@@ -982,8 +974,8 @@ void OJoinTableView::SelectConn(OTableConnection* pConn)
         OTableWindowListBox* pDestBox = pConnDest->GetListBox();
         if (pSourceBox && pDestBox)
         {
-            pSourceBox->SelectAll(FALSE);
-            pDestBox->SelectAll(FALSE);
+            pSourceBox->SelectAll(sal_False);
+            pDestBox->SelectAll(sal_False);
 
             SvLBoxEntry* pFirstSourceVisible = pSourceBox->GetFirstEntryInView();
             SvLBoxEntry* pFirstDestVisible = pDestBox->GetFirstEntryInView();
@@ -997,14 +989,14 @@ void OJoinTableView::SelectConn(OTableConnection* pConn)
                     SvLBoxEntry* pSourceEntry = pSourceBox->GetEntryFromText((*aIter)->GetData()->GetSourceFieldName());
                     if (pSourceEntry)
                     {
-                        pSourceBox->Select(pSourceEntry, TRUE);
+                        pSourceBox->Select(pSourceEntry, sal_True);
                         pSourceBox->MakeVisible(pSourceEntry);
                     }
 
                     SvLBoxEntry* pDestEntry = pDestBox->GetEntryFromText((*aIter)->GetData()->GetDestFieldName());
                     if (pDestEntry)
                     {
-                        pDestBox->Select(pDestEntry, TRUE);
+                        pDestBox->Select(pDestEntry, sal_True);
                         pDestBox->MakeVisible(pDestEntry);
                     }
 
@@ -1063,7 +1055,7 @@ sal_Int32 OJoinTableView::getConnectionCount(const OTableWindow* _pFromWin) cons
                             ::std::bind2nd(::std::mem_fun(&OTableConnection::isTableConnection),_pFromWin));
 }
 //------------------------------------------------------------------------------
-BOOL OJoinTableView::ExistsAConn(const OTableWindow* pFrom) const
+sal_Bool OJoinTableView::ExistsAConn(const OTableWindow* pFrom) const
 {
     DBG_CHKTHIS(OJoinTableView,NULL);
     return getTableConnections(pFrom) != m_vTableConnection.end();
@@ -1072,7 +1064,7 @@ BOOL OJoinTableView::ExistsAConn(const OTableWindow* pFrom) const
 void OJoinTableView::ClearAll()
 {
     DBG_CHKTHIS(OJoinTableView,NULL);
-    SetUpdateMode(FALSE);
+    SetUpdateMode(sal_False);
 
     HideTabWins();
 
@@ -1087,16 +1079,16 @@ void OJoinTableView::ClearAll()
     m_pSelectedConn		= NULL;
 
     // scroll to the upper left
-    ScrollPane(-GetScrollOffset().X(), TRUE, TRUE);
-    ScrollPane(-GetScrollOffset().Y(), FALSE, TRUE);
+    ScrollPane(-GetScrollOffset().X(), sal_True, sal_True);
+    ScrollPane(-GetScrollOffset().Y(), sal_False, sal_True);
     Invalidate();
 }
 
 //------------------------------------------------------------------------
-BOOL OJoinTableView::ScrollWhileDragging()
+sal_Bool OJoinTableView::ScrollWhileDragging()
 {
     DBG_CHKTHIS(OJoinTableView,NULL);
-    DBG_ASSERT(m_pDragWin != NULL, "OJoinTableView::ScrollWhileDragging darf nur waehrend Dragging eines Fensters aufgerufen werden !");
+    OSL_ENSURE(m_pDragWin != NULL, "OJoinTableView::ScrollWhileDragging darf nur waehrend Dragging eines Fensters aufgerufen werden !");
 
     // den Timer schon mal killen
     if (m_aDragScrollTimer.IsActive())
@@ -1107,19 +1099,19 @@ BOOL OJoinTableView::ScrollWhileDragging()
     Point aLowerRight(aDragWinPos.X() + aDragWinSize.Width(), aDragWinPos.Y() + aDragWinSize.Height());
 
     if (!m_bTrackingInitiallyMoved && (aDragWinPos == m_pDragWin->GetPosPixel()))
-        return TRUE;
+        return sal_True;
 
     // Darstellungsfehler vermeiden (wenn bei aktivem TrackingRect gescrollt wird)
     HideTracking();
 
-    BOOL bScrolling = FALSE;
-    BOOL bNeedScrollTimer = FALSE;
+    sal_Bool bScrolling = sal_False;
+    sal_Bool bNeedScrollTimer = sal_False;
 
     // An Fenstergrenzen scrollen
     // TODO : nur dann abfangen, wenn das Fenster komplett verschwinden wuerde (nicht, solange noch ein Pixel sichtbar ist)
     if( aDragWinPos.X() < 5 )
     {
-        bScrolling = ScrollPane( -LINE_SIZE, TRUE, TRUE );
+        bScrolling = ScrollPane( -LINE_SIZE, sal_True, sal_True );
         if( !bScrolling && (aDragWinPos.X()<0) )
             aDragWinPos.X() = 0;
 
@@ -1129,7 +1121,7 @@ BOOL OJoinTableView::ScrollWhileDragging()
 
     if( aLowerRight.X() > m_aOutputSize.Width() - 5 )
     {
-        bScrolling = ScrollPane( LINE_SIZE, TRUE, TRUE ) ;
+        bScrolling = ScrollPane( LINE_SIZE, sal_True, sal_True ) ;
         if( !bScrolling && ( aLowerRight.X() > m_aOutputSize.Width() ) )
             aDragWinPos.X() = m_aOutputSize.Width() - aDragWinSize.Width();
 
@@ -1139,7 +1131,7 @@ BOOL OJoinTableView::ScrollWhileDragging()
 
     if( aDragWinPos.Y() < 5 )
     {
-        bScrolling = ScrollPane( -LINE_SIZE, FALSE, TRUE );
+        bScrolling = ScrollPane( -LINE_SIZE, sal_False, sal_True );
         if( !bScrolling && (aDragWinPos.Y()<0) )
             aDragWinPos.Y() = 0;
 
@@ -1148,7 +1140,7 @@ BOOL OJoinTableView::ScrollWhileDragging()
 
     if( aLowerRight.Y() > m_aOutputSize.Height() - 5 )
     {
-        bScrolling = ScrollPane( LINE_SIZE, FALSE, TRUE );
+        bScrolling = ScrollPane( LINE_SIZE, sal_False, sal_True );
         if( !bScrolling && ( (aDragWinPos.Y() + aDragWinSize.Height()) > m_aOutputSize.Height() ) )
             aDragWinPos.Y() =  m_aOutputSize.Height() - aDragWinSize.Height();
 
@@ -1203,36 +1195,32 @@ void OJoinTableView::TabWinSized(OTableWindow* ptWhich, const Point& ptOldPositi
 }
 
 //------------------------------------------------------------------------------
-BOOL OJoinTableView::IsAddAllowed()
+sal_Bool OJoinTableView::IsAddAllowed()
 {
     DBG_CHKTHIS(OJoinTableView,NULL);
 
     // nicht wenn Db readonly
     if (m_pView->getController().isReadOnly())
-        return FALSE;
+        return sal_False;
 
     try
     {
         Reference< XConnection> xConnection = m_pView->getController().getConnection();
         if(!xConnection.is())
-            return FALSE;
+            return sal_False;
         // nicht wenn schon zuviele Tabellen
         Reference < XDatabaseMetaData > xMetaData( xConnection->getMetaData() );
 
         sal_Int32 nMax = xMetaData.is() ? xMetaData->getMaxTablesInSelect() : 0;
         if (nMax && nMax <= (sal_Int32)m_aTableMap.size())
-            return FALSE;
+            return sal_False;
     }
     catch(SQLException&)
     {
-        return FALSE;
+        return sal_False;
     }
 
-    // nicht wenn keine Joins moeglich
-//	if (!GetDatabase()->IsCapable(SDB_CAP_JOIN) && nMax <= GetTabWinCount())
-//		return FALSE;
-
-    return TRUE;
+    return sal_True;
 }
 // -----------------------------------------------------------------------------
 void OJoinTableView::executePopup(const Point& _aPos,OTableConnection* _pSelConnection)
@@ -1253,7 +1241,7 @@ void OJoinTableView::Command(const CommandEvent& rEvt)
 {
     DBG_CHKTHIS(OJoinTableView,NULL);
 
-    BOOL bHandled = FALSE;
+    sal_Bool bHandled = sal_False;
 
     switch (rEvt.GetCommand())
     {
@@ -1292,7 +1280,7 @@ void OJoinTableView::Command(const CommandEvent& rEvt)
                     }
                 }
             }
-            bHandled = TRUE;
+            bHandled = sal_True;
         }
     }
     if (!bHandled)
@@ -1303,12 +1291,12 @@ void OJoinTableView::Command(const CommandEvent& rEvt)
 OTableConnection* OJoinTableView::GetTabConn(const OTableWindow* pLhs,const OTableWindow* pRhs,bool _bSupressCrossOrNaturalJoin,const OTableConnection* _rpFirstAfter) const
 {
     OTableConnection* pConn = NULL;
-    DBG_ASSERT(pRhs || pLhs, "OJoinTableView::GetTabConn : invalid args !");
+    OSL_ENSURE(pRhs || pLhs, "OJoinTableView::GetTabConn : invalid args !");
         // only one NULL-arg allowed
 
     if ((!pLhs || pLhs->ExistsAConn()) && (!pRhs || pRhs->ExistsAConn()))
     {
-        BOOL bFoundStart = _rpFirstAfter ? FALSE : TRUE;
+        sal_Bool bFoundStart = _rpFirstAfter ? sal_False : sal_True;
 
         ::std::vector<OTableConnection*>::const_iterator aIter = m_vTableConnection.begin();
         ::std::vector<OTableConnection*>::const_iterator aEnd = m_vTableConnection.end();
@@ -1345,7 +1333,7 @@ OTableConnection* OJoinTableView::GetTabConn(const OTableWindow* pLhs,const OTab
                     pConn = pData;
 
                 if (pData == _rpFirstAfter)
-                    bFoundStart = TRUE;
+                    bFoundStart = sal_True;
             }
         }
     }
@@ -1355,7 +1343,7 @@ OTableConnection* OJoinTableView::GetTabConn(const OTableWindow* pLhs,const OTab
 //------------------------------------------------------------------------------
 long OJoinTableView::PreNotify(NotifyEvent& rNEvt)
 {
-    BOOL bHandled = FALSE;
+    sal_Bool bHandled = sal_False;
     switch (rNEvt.GetType())
     {
         case EVENT_COMMAND:
@@ -1367,10 +1355,10 @@ long OJoinTableView::PreNotify(NotifyEvent& rNEvt)
                 if (pData->GetMode() == COMMAND_WHEEL_SCROLL)
                 {
                     if (pData->GetDelta() > 0)
-                        ScrollPane(-10 * pData->GetScrollLines(), pData->IsHorz(), TRUE);
+                        ScrollPane(-10 * pData->GetScrollLines(), pData->IsHorz(), sal_True);
                     else
-                        ScrollPane(10 * pData->GetScrollLines(), pData->IsHorz(), TRUE);
-                    bHandled = TRUE;
+                        ScrollPane(10 * pData->GetScrollLines(), pData->IsHorz(), sal_True);
+                    bHandled = sal_True;
                 }
             }
         }
@@ -1391,7 +1379,7 @@ long OJoinTableView::PreNotify(NotifyEvent& rNEvt)
                         if (!HasChildPathFocus())
                             break;
 
-                        BOOL bForward = !pKeyEvent->GetKeyCode().IsShift();
+                        sal_Bool bForward = !pKeyEvent->GetKeyCode().IsShift();
                         // is there an active tab win ?
                         OTableWindowMapIterator aIter = m_aTableMap.begin();
                         OTableWindowMapIterator aEnd = m_aTableMap.end();
@@ -1717,7 +1705,7 @@ bool OJoinTableView::allowQueries() const
 // -----------------------------------------------------------------------------
 void OJoinTableView::onNoColumns_throw()
 {
-    OSL_ENSURE( false, "OTableWindow::onNoColumns_throw: cannot really handle this!" );
+    OSL_FAIL( "OTableWindow::onNoColumns_throw: cannot really handle this!" );
     throw SQLException();
 }
 //------------------------------------------------------------------------------
